@@ -776,7 +776,7 @@ bool EventStream::loadEventData( int event_id )
         else
             snprintf( event_data->path, sizeof(event_data->path), "%s/%s/%ld/%ld", staticConfig.PATH_WEB.c_str(), config.dir_events, event_data->monitor_id, event_data->event_id );
     }
-    event_data->frame_count = atoi(dbrow[2]);
+    event_data->frame_count = dbrow[2] == NULL ? 0 : atoi(dbrow[2]);
     event_data->duration = atof(dbrow[4]);
 
     updateFrameRate( (double)event_data->frame_count/event_data->duration );
@@ -877,6 +877,11 @@ void EventStream::processCommand( const CmdMsg *msg )
                 // Clear paused flag
                 paused = false;
             }
+
+	    // If we are in single event mode and at the last frame, replay the current event
+	    if ( (mode == MODE_SINGLE) && (curr_frame_id == event_data->frame_count) )
+		curr_frame_id = 1;
+
             replay_rate = ZM_RATE_BASE;
             break;
         }
@@ -1050,7 +1055,7 @@ void EventStream::processCommand( const CmdMsg *msg )
             if ( replay_rate >= 0 )
                 curr_frame_id = 0;
             else
-                curr_frame_id = event_data->frame_count-1;
+                curr_frame_id = event_data->frame_count+1;
             paused = false;
             forceEventChange = true;
             break;
@@ -1059,7 +1064,7 @@ void EventStream::processCommand( const CmdMsg *msg )
         {
             Debug( 1, "Got NEXT command" );
             if ( replay_rate >= 0 )
-                curr_frame_id = event_data->frame_count-1;
+                curr_frame_id = event_data->frame_count+1;
             else
                 curr_frame_id = 0;
             paused = false;
@@ -1168,10 +1173,9 @@ void EventStream::checkEventLoaded()
                 loadEventData( event_id );
 
                 Debug( 2, "Current frame id = %d", curr_frame_id );
-//		When loading a new event, always set the current frame id to the first frame rather than the last
-//                if ( curr_frame_id <= 0 )
-//                    curr_frame_id = event_data->frame_count;
-//                else
+                if ( replay_rate < 0 )
+                    curr_frame_id = event_data->frame_count;
+                else
                     curr_frame_id = 1;
                 Debug( 2, "New frame id = %d", curr_frame_id );
             }
