@@ -54,7 +54,7 @@ static PixelFormat getFfPixFormatFromV4lPalette( int v4l_version, int palette )
     {
         switch( palette )
         {
-#ifdef V4L2_PIX_FMT_RGB444
+#if defined(V4L2_PIX_FMT_RGB444) && defined(PIX_FMT_RGB444)
             case V4L2_PIX_FMT_RGB444 :
                 pixFormat = PIX_FMT_RGB444;
                 break;
@@ -283,7 +283,7 @@ AVFrame **LocalCamera::capturePictures = 0;
 
 LocalCamera *LocalCamera::last_camera = NULL;
 
-LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel, int p_standard, const std::string &p_method, int p_width, int p_height, int p_colours, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture, unsigned int p_extras) :
+LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel, int p_standard, bool p_v4l_multi_buffer, unsigned int p_v4l_captures_per_frame, const std::string &p_method, int p_width, int p_height, int p_colours, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture, unsigned int p_extras) :
     Camera( p_id, LOCAL_SRC, p_width, p_height, p_colours, ZM_SUBPIX_ORDER_DEFAULT_FOR_COLOUR(p_colours), p_brightness, p_contrast, p_hue, p_colour, p_capture ),
     device( p_device ),
     channel( p_channel ),
@@ -296,6 +296,8 @@ LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel,
     // do the initial opening etc
     device_prime = (camera_count++ == 0);
     v4l_version = (p_method=="v4l2"?2:1);
+	v4l_multi_buffer = p_v4l_multi_buffer;
+	v4l_captures_per_frame = p_v4l_captures_per_frame;
     
     if ( capture )
     {
@@ -363,15 +365,13 @@ LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel,
 			if ( width != last_camera->width || height != last_camera->height )
 				Warning( "Different capture sizes defined for monitors sharing same device, results may be unpredictable or completely wrong" );
 		}
-	}
 	
 #if HAVE_LIBSWSCALE
-	if( capture ) {
 		/* Get ffmpeg pixel format based on capture palette and endianness */
 		capturePixFormat = getFfPixFormatFromV4lPalette( v4l_version, palette );
 		imagePixFormat = PIX_FMT_NONE;
-	}
 #endif // HAVE_LIBSWSCALE   
+	}
 
 	/* V4L2 format matching */
 #if ZM_HAS_V4L2
@@ -423,6 +423,7 @@ LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel,
 				Panic("Unexpected colours: %d",colours);
 			}
 			if( capture ) {
+#if LIBSWSCALE_VERSION_INT >= AV_VERSION_INT(0, 8, 0)
 				if(!sws_isSupportedInput(capturePixFormat)) {
 					Error("swscale does not support the used capture format: %c%c%c%c",(capturePixFormat)&0xff,((capturePixFormat>>8)&0xff),((capturePixFormat>>16)&0xff),((capturePixFormat>>24)&0xff));
 					conversion_type = 2; /* Try ZM format conversions */
@@ -431,6 +432,7 @@ LocalCamera::LocalCamera( int p_id, const std::string &p_device, int p_channel,
 					Error("swscale does not support the target format: %c%c%c%c",(imagePixFormat)&0xff,((imagePixFormat>>8)&0xff),((imagePixFormat>>16)&0xff),((imagePixFormat>>24)&0xff));
 					conversion_type = 2; /* Try ZM format conversions */
 				}
+#endif
 			}
 #else
 			/* Don't have swscale, see what we can do */
@@ -781,13 +783,18 @@ void LocalCamera::Initialise()
         Debug( 3, "Setting up request buffers" );
        
         memset( &v4l2_data.reqbufs, 0, sizeof(v4l2_data.reqbufs) );
-        if ( channel_count > 1 )
-            if ( config.v4l_multi_buffer )
+        if ( channel_count > 1 ) {
+			Debug( 3, "Channel count is %d", channel_count );
+            if ( v4l_multi_buffer ){
                 v4l2_data.reqbufs.count = 2*channel_count;
-            else
+            } else {
                 v4l2_data.reqbufs.count = 1;
-        else
+			}
+        } else {
             v4l2_data.reqbufs.count = 8;
+		}
+		Debug( 3, "Request buffers count is %d", v4l2_data.reqbufs.count );
+
         v4l2_data.reqbufs.type = v4l2_data.fmt.type;
         v4l2_data.reqbufs.memory = V4L2_MEMORY_MMAP;
 
@@ -803,10 +810,10 @@ void LocalCamera::Initialise()
             }
         }
 
-        if ( v4l2_data.reqbufs.count < (config.v4l_multi_buffer?2:1) )
+        if ( v4l2_data.reqbufs.count < (v4l_multi_buffer?2:1) )
             Fatal( "Insufficient buffer memory %d on video device", v4l2_data.reqbufs.count );
 
-        Debug( 3, "Setting up %d data buffers", v4l2_data.reqbufs.count );
+		Debug( 3, "Setting up data buffers: Channels %d MultiBuffer %d Buffers: %d", channel_count, v4l_multi_buffer, v4l2_data.reqbufs.count );
 
         v4l2_data.buffers = new V4L2MappedBuffer[v4l2_data.reqbufs.count];
 #if HAVE_LIBSWSCALE
@@ -967,7 +974,7 @@ void LocalCamera::Initialise()
         Debug( 3, "Setting up request buffers" );
         if ( ioctl( vid_fd, VIDIOCGMBUF, &v4l1_data.frames ) < 0 )
             Fatal( "Failed to setup memory: %s", strerror(errno) );
-        if ( channel_count > 1 && !config.v4l_multi_buffer )
+        if ( channel_count > 1 && !v4l_multi_buffer )
             v4l1_data.frames.frames = 1;
         v4l1_data.buffers = new video_mmap[v4l1_data.frames.frames];
         Debug( 4, "vmb.frames = %d", v4l1_data.frames.frames );
@@ -1974,7 +1981,11 @@ int LocalCamera::Capture( Image &image )
 	
 	int captures_per_frame = 1;
 	if ( channel_count > 1 )
-		captures_per_frame = config.captures_per_frame;
+		captures_per_frame = v4l_captures_per_frame;
+	if ( captures_per_frame <= 0 ) {
+		captures_per_frame = 1;
+		Warning( "Invalid Captures Per Frame setting: %d", captures_per_frame );
+	} 
 	
 	
     // Do the capture, unless we are the second or subsequent camera on a channel, in which case just reuse the buffer
@@ -2126,12 +2137,16 @@ int LocalCamera::PostCapture()
                     return( -1 );
                 }
             }
-            Debug( 3, "Requeueing buffer %d", v4l2_data.bufptr->index );
-            if ( vidioctl( vid_fd, VIDIOC_QBUF, v4l2_data.bufptr ) < 0 )
-            {
-                Error( "Unable to requeue buffer %d: %s", v4l2_data.bufptr->index, strerror(errno) )
-                return( -1 );
-            }
+			if ( v4l2_data.bufptr ) {
+				Debug( 3, "Requeueing buffer %d", v4l2_data.bufptr->index );
+				if ( vidioctl( vid_fd, VIDIOC_QBUF, v4l2_data.bufptr ) < 0 )
+				{
+					Error( "Unable to requeue buffer %d: %s", v4l2_data.bufptr->index, strerror(errno) )
+						return( -1 );
+				}
+			} else {
+                Error( "Unable to requeue buffer due to not v4l2_data" )
+			}
         }
 #endif // ZM_HAS_V4L2
 #if ZM_HAS_V4L1
