@@ -239,6 +239,9 @@ void Logger::terminate()
 
     if ( mSyslogLevel > NOLOG )
         closeSyslog();
+
+    if ( mDatabaseLevel > NOLOG )
+        closeDatabase();
 }
 
 bool Logger::boolEnv( const std::string &name, bool defaultValue )
@@ -468,6 +471,15 @@ void Logger::closeFile()
     }
 }
 
+void Logger::closeDatabase()
+{
+    if ( mDbConnected )
+    {
+        mysql_close( &mDbConnection );
+        mDbConnected = false;
+    }
+}
+
 void Logger::openSyslog()
 {
     (void) openlog( mId.c_str(), LOG_PID|LOG_NDELAY, LOG_LOCAL1 );
@@ -604,5 +616,6 @@ void logInit( const char *name, const Logger::Options &options )
 
 void logTerm()
 {
-    Logger::fetch()->terminate();
+    if ( Logger::smInstance )
+        delete Logger::smInstance;
 }
