@@ -115,6 +115,7 @@ private:
 
 public:
     friend void logInit( const char *name, const Options &options );
+    friend void logTerm();
 
     static Logger *fetch()
     {
@@ -182,6 +183,7 @@ private:
     void closeFile();
     void openSyslog();
     void closeSyslog();
+    void closeDatabase();
 
 public:
     void logPrint( bool hex, const char * const file, const int line, const int level, const char *fstring, ... );
