@@ -97,17 +97,21 @@ bool User::canAccess( int monitor_id )
 }
 
 // Function to load a user from username and password
+// Please note that in auth relay mode = none, password is NULL
 User *zmLoadUser( const char *username, const char *password )
 {
     char sql[ZM_SQL_SML_BUFSIZ] = "";
+    char safer_username[65]; // current db username size is 32
+    char safer_password[129]; // current db password size is 64
 
-	if ( password )
-	{
-		snprintf( sql, sizeof(sql), "select Username, Password, Enabled, Stream+0, Events+0, Control+0, Monitors+0, System+0, MonitorIds from Users where Username = '%s' and Password = password('%s') and Enabled = 1", username, password );
-	}
-	else
-	{
-		snprintf( sql, sizeof(sql), "select Username, Password, Enabled, Stream+0, Events+0, Control+0, Monitors+0, System+0, MonitorIds from Users where Username = '%s' and Enabled = 1", username );
+	// According to docs, size of safer_whatever must be 2*length+1 due to unicode conversions + null terminator.
+    mysql_real_escape_string(&dbconn, safer_username, username, strlen( username ) );
+
+	if ( password ) {
+		mysql_real_escape_string(&dbconn, safer_password, password, strlen( password ) );
+		snprintf( sql, sizeof(sql), "select Username, Password, Enabled, Stream+0, Events+0, Control+0, Monitors+0, System+0, MonitorIds from Users where Username = '%s' and Password = password('%s') and Enabled = 1", safer_username, safer_password );
+	} else {
+		snprintf( sql, sizeof(sql), "select Username, Password, Enabled, Stream+0, Events+0, Control+0, Monitors+0, System+0, MonitorIds from Users where Username = '%s' and Enabled = 1", safer_username );
 	}
 
 	if ( mysql_query( &dbconn, sql ) )
