@@ -51,6 +51,7 @@ $statusData = array(
             "AlarmFrameCount" => true,
             "SectionLength" => true,
             "FrameSkip" => true,
+            "MotionFrameSkip" => true,
             "MaxFPS" => true,
             "AlarmMaxFPS" => true,
             "FPSReportInterval" => true,
@@ -246,12 +247,15 @@ function collectData()
             {
                 $index = 0;
                 $where = array();
-                foreach( $entitySpec['selector'] as $selector )
-                {
-                    if ( is_array( $selector ) )
-                        $where[] = $selector['selector']." = ".dbEscape($id[$index]);
-                    else
-                        $where[] = $selector." = ".dbEscape($id[$index]);
+				$values = array();
+                foreach( $entitySpec['selector'] as $selector ) {
+                    if ( is_array( $selector ) ) {
+                        $where[] = $selector['selector'].' = ?';
+						$values[] = validInt($id[$index]);
+                    } else {
+                        $where[] = $selector.' = ?';
+						$values[] = validInt($id[$index]);
+					}
                     $index++;
                 }
                 $sql .= " where ".join( " and ", $where );
@@ -259,27 +263,25 @@ function collectData()
             if ( $groupSql )
                 $sql .= " group by ".join( ",", array_unique( $groupSql ) );
             if ( !empty($_REQUEST['sort']) )
-                $sql .= " order by ".dbEscape($_REQUEST['sort']);
+                $sql .= " order by ".$_REQUEST['sort'];
             if ( !empty($entitySpec['limit']) )
                 $limit = $entitySpec['limit'];
             elseif ( !empty($_REQUEST['count']) )
-                $limit = dbEscape($_REQUEST['count']);
-            if ( !empty( $limit ) )
-                $sql .= " limit ".$limit;
-            if ( isset($limit) && $limit == 1 )
-            {
-                if ( $sqlData = dbFetchOne( $sql ) )
-                {
+                $limit = validInt($_REQUEST['count']);
+			$limit_offset="";
+			if ( !empty($_REQUEST['offset']) )
+				$limit_offset = validInt($_REQUEST['offset']) . ", ";
+			if ( !empty( $limit ) )
+                $sql .= " limit ".$limit_offset.$limit;
+            if ( isset($limit) && $limit == 1 ) {
+                if ( $sqlData = dbFetchOne( $sql, NULL, $values ) ) {
                     foreach ( $postFuncs as $element=>$func )
                         $sqlData[$element] = eval( 'return( '.$func.'( $sqlData ) );' );
                     $data = array_merge( $data, $sqlData );
                 }
-            }
-            else
-            {
+            } else {
                 $count = 0;
-                foreach( dbFetchAll( $sql ) as $sqlData )
-                {
+                foreach( dbFetchAll( $sql, NULL, $values ) as $sqlData ) {
                     foreach ( $postFuncs as $element=>$func )
                         $sqlData[$element] = eval( 'return( '.$func.'( $sqlData ) );' );
                     $data[] = $sqlData;
@@ -332,32 +334,32 @@ switch( $_REQUEST['layout'] )
 
 function getFrameImage()
 {
-    $eventId = dbEscape($_REQUEST['id'][0]);
-    $frameId = dbEscape($_REQUEST['id'][1]);
+    $eventId = $_REQUEST['id'][0];
+    $frameId = $_REQUEST['id'][1];
 
-    $sql = "select * from Frames where EventId = '".$eventId."' and FrameId = '".$frameId."'";
-    if ( !($frame = dbFetchOne( $sql )) )
+    $sql = 'select * from Frames where EventId = ? and FrameId = ?';
+    if ( !($frame = dbFetchOne( $sql, NULL, array( $eventId, $frameId ) )) )
     {
         $frame = array();
         $frame['EventId'] = $eventId;
         $frame['FrameId'] = $frameId;
         $frame['Type'] = "Virtual";
     }
-    $event = dbFetchOne( "select * from Events where Id = '".$frame['EventId']."'" );
+    $event = dbFetchOne( 'select * from Events where Id = ?', NULL, array( $frame['EventId'] ) );
     $frame['Image'] = getImageSrc( $event, $frame, SCALE_BASE );
     return( $frame );
 }
 
 function getNearFrame()
 {
-    $eventId = dbEscape($_REQUEST['id'][0]);
-    $frameId = dbEscape($_REQUEST['id'][1]);
+    $eventId = $_REQUEST['id'][0];
+    $frameId = $_REQUEST['id'][1];
 
-    $sql = "select FrameId from Frames where EventId = '".$eventId."' and FrameId <= '".$frameId."' order by FrameId desc limit 1";
-    if ( !$nearFrameId = dbFetchOne( $sql, 'FrameId' ) )
+    $sql = 'select FrameId from Frames where EventId = ? and FrameId <= ? order by FrameId desc limit 1';
+    if ( !$nearFrameId = dbFetchOne( $sql, 'FrameId', array( $eventId, $frameId ) ) )
     {
-        $sql = "select * from Frames where EventId = '".$eventId."' and FrameId > '".$frameId."' order by FrameId asc limit 1";
-        if ( !$nearFrameId = dbFetchOne( $sql, 'FrameId' ) )
+        $sql = 'select * from Frames where EventId = ? and FrameId > ? order by FrameId asc limit 1';
+        if ( !$nearFrameId = dbFetchOne( $sql, 'FrameId', array( $eventId, $frameId ) ) )
         {
             return( array() );
         }
@@ -371,8 +373,8 @@ function getNearEvents()
 {
     global $user, $sortColumn, $sortOrder;
 
-    $eventId = dbEscape($_REQUEST['id']);
-    $event = dbFetchOne( "select * from Events where Id = '".$eventId."'" );
+    $eventId = $_REQUEST['id'];
+    $event = dbFetchOne( 'select * from Events where Id = ?', NULL, array( $eventId ) );
 
     parseFilter( $_REQUEST['filter'] );
     parseSort();
