@@ -132,6 +132,7 @@ $SLANG = array(
     'BadFPSReportInterval' => 'Der FPS-Intervall-Puffer-Z&auml;hler muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadFormat'            => 'Das Format muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadFrameSkip'         => 'Der Auslassz&auml;hler f&uuml;r Frames muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
+    'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Die H&ouml;he muss auf einen g&uuml;ltigen Wert eingestellt sein',
     'BadHost'              => 'Der Host muss auf eine g&uuml;ltige IP-Adresse oder einen Hostnamen (ohne http://) eingestellt sein',
     'BadImageBufferCount'  => 'Die Gr&ouml;&szlig;e des Bildpuffers muss ganzzahlig 10 oder gr&ouml;&szlig;er sein',
@@ -152,6 +153,7 @@ $SLANG = array(
     'BadWebColour'         => 'Die Webfarbe muss auf einen g&uuml;ltigen Farbwert eingestellt sein',
     'BadWidth'             => 'Die Breite muss auf einen g&uuml;ltigen Wert eingestellt sein',
     'Bandwidth'            => 'Bandbreite',
+    'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'               => 'Blob-Pixel',
     'BlobSizes'            => 'Blobgr&ouml;&szlig;e',
     'Blobs'                => 'Blobs',
@@ -320,6 +322,12 @@ $SLANG = array(
     'First'                => 'Erstes',
     'FlippedHori'          => 'Horizontal gespiegelt',
     'FlippedVert'          => 'Vertikal gespiegelt',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                => 'Fokus',
     'ForceAlarm'           => 'Unbedingter Alarm',
     'Format'               => 'Format',
@@ -327,6 +335,7 @@ $SLANG = array(
     'FrameId'              => 'Bild-ID',
     'FrameRate'            => 'Abspielgeschwindigkeit',
     'FrameSkip'            => 'Bilder auslassen',
+    'MotionFrameSkip'      => 'Motion Frame Skip',
     'Frames'               => 'Bilder',
     'Func'                 => 'Fkt.',
     'Function'             => 'Funktion',
@@ -370,6 +379,7 @@ $SLANG = array(
     'Last'                 => 'Letztes',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
     'Level'                => 'Level',                  // Added - 2011-06-16
+    'Libvlc'               => 'Libvlc',
     'LimitResultsPost'     => 'Ergebnisse;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Begrenze nur auf die ersten', // This is used at the beginning of the phrase 'Limit to first N results only'
     'Line'                 => 'Line',                   // Added - 2011-06-16
@@ -463,6 +473,11 @@ $SLANG = array(
     'Month'                => 'Monat',
     'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Bewegung',
+    'MtgDefault'           => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'           => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'           => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'           => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'           => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'             => 'muss groesser oder gleich sein wie',
     'MustBeLe'             => 'muss kleiner oder gleich sein wie',
     'MustConfirmPassword'  => 'Sie m&uuml;ssen das Passwort best&auml;tigen.',
@@ -631,6 +646,10 @@ $SLANG = array(
     'TimeDelta'            => 'Zeitdifferenz',
     'TimeStamp'            => 'Zeitstempel',
     'Timeline'             => 'Zeitlinie',
+    'TimelineTip1'         => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'         => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'         => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'         => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Zeitstempel',
     'TimestampLabelFormat' => 'Format des Zeitstempels',
     'TimestampLabelX'      => 'Zeitstempel-X',
@@ -708,6 +727,7 @@ $SLANG = array(
     'ZoneMinMaxPixelThres' => 'Min./max. Pixelschwellwert',
     'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Bildauslassrate bei System&uuml;berlastung',
+    'ZoneExtendAlarmFrames' => 'Alarmstatus nach Ende f&uuml;r Frames aufrechterhalten',
     'Zones'                => 'Zonen',
     'Zoom'                 => 'Zoom',
     'ZoomIn'               => 'Hineinzoomen',
@@ -840,6 +860,20 @@ function zmVlang( $langVarArray, $count )
 // These overrides are in the form show below where the array key represents the option name minus the initial ZM_
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 //    'LANG_DEFAULT' => array(
 //        'Prompt' => "This is a new prompt for this option",
 //        'Help' => "This is some new help for this option which will be displayed in the popup window when the ? is clicked"
