@@ -133,6 +133,7 @@ $SLANG = array(
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
     'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
+    'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Height must be set to a valid value',
     'BadHost'              => 'Host must be set to a valid ip address or hostname, do not include http://',
     'BadImageBufferCount'  => 'Image buffer size must be an integer of 10 or more',
@@ -153,6 +154,7 @@ $SLANG = array(
     'BadWebColour'         => 'Web colour must be a valid web colour string',
     'BadWidth'             => 'Width must be set to a valid value',
     'Bandwidth'            => 'Bndbrede',
+    'BandwidthHead'        => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'               => 'Blob Px',
     'BlobSizes'            => 'Blob Strelse',
     'Blobs'                => 'Blobs',
@@ -321,6 +323,12 @@ $SLANG = array(
     'First'                => 'Frste',
     'FlippedHori'          => 'Flipped Horizontally',
     'FlippedVert'          => 'Flipped Vertically',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                => 'Fokus',
     'ForceAlarm'           => 'Tving Alarm',
     'Format'               => 'Format',
@@ -328,6 +336,7 @@ $SLANG = array(
     'FrameId'              => 'Billede Id',
     'FrameRate'            => 'Billede Rate',
     'FrameSkip'            => 'Billede Skip',
+    'MotionFrameSkip'      => 'Motion Frame Skip',
     'Frames'               => 'Billede',
     'Func'                 => 'Func',
     'Function'             => 'Funktion',
@@ -371,6 +380,7 @@ $SLANG = array(
     'Last'                 => 'Sidste',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
     'Level'                => 'Level',                  // Added - 2011-06-16
+    'Libvlc'               => 'Libvlc',
     'LimitResultsPost'     => 'results only;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Limit to first', // This is used at the beginning of the phrase 'Limit to first N results only'
     'Line'                 => 'Line',                   // Added - 2011-06-16
@@ -464,6 +474,11 @@ $SLANG = array(
     'Month'                => 'Mned',
     'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Flyt',
+    'MtgDefault'            => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'            => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'            => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'            => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'            => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'             => 'skal vre stre end eller ligmed',
     'MustBeLe'             => 'Skal vre mindre end eller ligmed',
     'MustConfirmPassword'  => 'Du skal konfimere password',
@@ -632,6 +647,10 @@ $SLANG = array(
     'TimeDelta'            => 'Time Delta',
     'TimeStamp'            => 'Tids Stempel',
     'Timeline'             => 'Timeline',
+    'TimelineTip1'         => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'         => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'         => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'         => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Tidsstempel',
     'TimestampLabelFormat' => 'Tidsstempel Mrknings Format',
     'TimestampLabelX'      => 'Tidsstempel Mrkning X',
@@ -709,6 +728,7 @@ $SLANG = array(
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
     'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
+    'ZoneExtendAlarmFrames' => 'Extend Alarm Frame Count',
     'Zones'                => 'Zoner',
     'Zoom'                 => 'Zoom',
     'ZoomIn'               => 'Zoom In',
@@ -841,6 +861,20 @@ function zmVlang( $langVarArray, $count )
 // These overrides are in the form show below where the array key represents the option name minus the initial ZM_
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 //    'LANG_DEFAULT' => array(
 //        'Prompt' => "This is a new prompt for this option",
 //        'Help' => "This is some new help for this option which will be displayed in the popup window when the ? is clicked"
