@@ -141,6 +141,7 @@ $SLANG = array(
     'BadFormat'             => 'Format must be set to a valid value',
     'BadFPSReportInterval'  => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFrameSkip'          => 'Frame skip count must be an integer of zero or more',
+    'BadMotionFrameSkip'    => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'             => 'Height must be set to a valid value',
     'BadHost'               => 'Host must be set to a valid ip address or hostname, do not include http://',
     'BadImageBufferCount'   => 'Image buffer size must be an integer of 10 or more',
@@ -162,6 +163,7 @@ $SLANG = array(
     'BadWebColour'          => 'Web colour must be a valid web colour string',
     'BadWidth'              => 'Width must be set to a valid value',
     'Bandwidth'             => 'Bandwidth',
+    'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'                => 'Blob Px',
     'Blobs'                 => 'Blobs',
     'BlobSizes'             => 'Blob Sizes',
@@ -324,6 +326,12 @@ $SLANG = array(
     'First'                 => 'First',
     'FlippedHori'           => 'Flipped Horizontally',
     'FlippedVert'           => 'Flipped Vertically',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                 => 'Focus',
     'ForceAlarm'            => 'Force Alarm',
     'Format'                => 'Format',
@@ -334,6 +342,7 @@ $SLANG = array(
     'FrameRate'             => 'Frame Rate',
     'Frames'                => 'Frames',
     'FrameSkip'             => 'Frame Skip',
+    'MotionFrameSkip'       => 'Motion Frame Skip',
     'FTP'                   => 'FTP',
     'Func'                  => 'Func',
     'Function'              => 'Function',
@@ -467,6 +476,11 @@ $SLANG = array(
     'Montage'               => 'Montage',
     'Month'                 => 'Month',
     'Move'                  => 'Move',
+    'MtgDefault'            => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'            => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'            => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'            => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'            => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'              => 'must be greater than or equal to',
     'MustBeLe'              => 'must be less than or equal to',
     'MustConfirmPassword'   => 'You must confirm the password',
@@ -631,6 +645,10 @@ $SLANG = array(
     'Tilt'                  => 'Tilt',
     'TimeDelta'             => 'Time Delta',
     'Timeline'              => 'Timeline',
+    'TimelineTip1'          => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'          => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'          => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'          => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'TimestampLabelFormat'  => 'Timestamp Label Format',
     'TimestampLabelX'       => 'Timestamp Label X',
     'TimestampLabelY'       => 'Timestamp Label Y',
@@ -682,6 +700,9 @@ $SLANG = array(
     'ViewEvent'             => 'View Event',
     'ViewPaged'             => 'View Paged',
     'View'                  => 'View',
+	'V4L'					=> 'V4L',
+	'V4LCapturesPerFrame'	=> 'Captures Per Frame',
+	'V4LMultiBuffer'		=> 'Multi Buffering',
     'Wake'                  => 'Wake',
     'WarmupFrames'          => 'Warmup Frames',
     'Watch'                 => 'Watch',
@@ -709,6 +730,7 @@ $SLANG = array(
     'ZoneMinMaxFiltArea'    => 'Min/Max Filtered Area',
     'ZoneMinMaxPixelThres'  => 'Min/Max Pixel Threshold (0-255)',
     'ZoneOverloadFrames'    => 'Overload Frame Ignore Count',
+    'ZoneExtendAlarmFrames' => 'Extend Alarm Frame Count',
     'Zones'                 => 'Zones',
     'Zone'                  => 'Zone',
     'ZoomIn'                => 'Zoom In',
@@ -841,6 +863,20 @@ function zmVlang( $langVarArray, $count )
 // These overrides are in the form show below where the array key represents the option name minus the initial ZM_
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 //    'LANG_DEFAULT' => array(
 //        'Prompt' => "This is a new prompt for this option",
 //        'Help' => "This is some new help for this option which will be displayed in the popup window when the ? is clicked"
