@@ -83,6 +83,7 @@ $SLANG = array(
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
     'BadFrameSkip'         => 'Frame skip count must be an integer of zero or more',
+    'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Height must be set to a valid value',
     'BadHost'              => 'Host must be set to a valid ip address or hostname, do not include http://',
     'BadImageBufferCount'  => 'Image buffer size must be an integer of 10 or more',
@@ -103,6 +104,7 @@ $SLANG = array(
     'BadWebColour'         => 'Web colour must be a valid web colour string',
     'BadWidth'             => 'Width must be set to a valid value',
     'Bandwidth'            => 'Velocidad',
+    'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'               => 'Blob Px',
     'BlobSizes'            => 'Blob Sizes',
     'Blobs'                => 'Blobs',
@@ -271,6 +273,12 @@ $SLANG = array(
     'First'                => 'Primero',
     'FlippedHori'          => 'Flipped Horizontally',
     'FlippedVert'          => 'Flipped Vertically',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                => 'Focus',
     'ForceAlarm'           => 'Forzar Alarma',
     'Format'               => 'Format',
@@ -278,6 +286,7 @@ $SLANG = array(
     'FrameId'              => 'Id Cuadro',
     'FrameRate'            => 'Velocidad del video',
     'FrameSkip'            => 'Saltear Cuadro',
+    'MotionFrameSkip'      => 'Motion Frame Skip',
     'Frames'               => 'Cuadros',
     'Func'                 => 'Func',
     'Function'             => 'Funcin',
@@ -321,6 +330,7 @@ $SLANG = array(
     'Last'                 => 'Ultimo',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
     'Level'                => 'Level',                  // Added - 2011-06-16
+    'Libvlc'               => 'Libvlc',
     'LimitResultsPost'     => 'Resultados;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'Solo los primeros', // This is used at the beginning of the phrase 'Limit to first N results only'
     'Line'                 => 'Line',                   // Added - 2011-06-16
@@ -414,6 +424,11 @@ $SLANG = array(
     'Month'                => 'Mes',
     'More'                 => 'More',                   // Added - 2011-06-16
     'Move'                 => 'Move',
+    'MtgDefault'           => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'           => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'           => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'           => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'           => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'             => 'Debe ser mayor o igual que',
     'MustBeLe'             => 'Debe ser menor o igual que',
     'MustConfirmPassword'  => 'Debe confirmar la contrasea',
@@ -582,6 +597,10 @@ $SLANG = array(
     'TimeDelta'            => 'Hora Delta',
     'TimeStamp'            => 'Etiqueta Hora',
     'Timeline'             => 'Timeline',
+    'TimelineTip1'         => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'         => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'         => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'         => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Etiqueta Hora',
     'TimestampLabelFormat' => 'Formato Etiqueta Hora',
     'TimestampLabelX'      => 'Eje X Etiqueta Hora',
@@ -659,6 +678,7 @@ $SLANG = array(
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
     'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame Ignore Count',
+    'ZoneExtendAlarmFrames' => 'Extend Alarm Frame Count',
     'Zones'                => 'Zonas',
     'Zoom'                 => 'Zoom',
     'ZoomIn'               => 'Zoom In',
@@ -697,6 +717,20 @@ function zmVlang( $langVarArray, $count )
 }
 
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 );
 
 ?>
