@@ -130,6 +130,7 @@ $SLANG = array(
     'BadFPSReportInterval'  => 'El registro de intervalo de recuento búfer de MPS debe ser un entero de 100 o más',
     'BadFormat'             => 'El formato debe tener un valor válido',
     'BadFrameSkip'          => 'El número de omisión de marcos debe ser un entero de cero o más',
+    'BadMotionFrameSkip'    => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'             => 'La altura debe tener un valor válido',
     'BadHost'               => 'El host debe tener una dirección ip o nombre de host válidos, no incluir http://',
     'BadImageBufferCount'   => 'El tamaño de búfer de imagen debe serun entero de 10 o más',
@@ -150,6 +151,7 @@ $SLANG = array(
     'BadWebColour'          => 'El color web debe ser una cadena de color web válida',
     'BadWidth'              => 'El ancho debe tener un valor válido',
     'Bandwidth'             => 'Ancho de banda',
+    'BandwidthHead'         => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'                => 'Px gota',
     'BlobSizes'             => 'Tamaño gotas',
     'Blobs'                 => 'Gotas',
@@ -317,6 +319,12 @@ $SLANG = array(
     'First'                 => 'Primero',
     'FlippedHori'           => 'Girado horizontalmente',
     'FlippedVert'           => 'Girado verticalmente',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                 => 'Enfoque',
     'ForceAlarm'            => 'Forzar alama',
     'Format'                => 'Formato',
@@ -324,6 +332,7 @@ $SLANG = array(
     'FrameId'               => 'Id del marco',
     'FrameRate'             => 'Ratío del marco',
     'FrameSkip'             => 'Omisión de marcos',
+    'MotionFrameSkip'       => 'Motion Frame Skip',
     'Frames'                => 'Marcos',
     'Func'                  => 'Func',
     'Function'              => 'Función',
@@ -367,6 +376,7 @@ $SLANG = array(
     'Last'                  => 'Último',
     'Layout'                => 'Diseño',
     'Level'                 => 'Nivel',
+    'Libvlc'               => 'Libvlc',
     'LimitResultsPost'      => 'Sólo resultados', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'       => 'Limitar al primero', // This is used at the beginning of the phrase 'Limit to first N results only'
     'Line'                  => 'Línea',
@@ -460,6 +470,11 @@ $SLANG = array(
     'Month'                 => 'Mes',
     'More'                  => 'Más',
     'Move'                  => 'Mover',
+    'MtgDefault'            => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'            => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'            => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'            => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'            => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'              => 'debe ser mayor o igual que',
     'MustBeLe'              => 'debe ser menor o igual que',
     'MustConfirmPassword'   => 'Debe confirmar la contraseña',
@@ -627,6 +642,10 @@ $SLANG = array(
     'TimeDelta'             => 'Delta del tiempo',
     'TimeStamp'             => 'Marca de tiempo',
     'Timeline'              => 'Línea de tiempo',
+    'TimelineTip1'          => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'          => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'          => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'          => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'             => 'Marca de tiempo',
     'TimestampLabelFormat'  => 'Formato de hora multinacional',
     'TimestampLabelX'       => 'Etiqueta de tiempo X',
@@ -742,6 +761,20 @@ function zmVlang( $langVarArray, $count )
 
 
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 );
 
 ?>
