@@ -75,9 +75,9 @@ $SLANG = array(
     '32BitColour'          => 'Couleur 32 bit',          // Added - 2011-06-15
     '8BitGrey'             => 'Gris 8 bit',
     'Action'               => 'Action',
-    'Actual'               => 'Rel',
+    'Actual'               => 'Réel',
     'AddNewControl'        => 'Add New Control',
-    'AddNewMonitor'        => 'Aj. nouv. cran',
+    'AddNewMonitor'        => 'Aj. nouv. écran',
     'AddNewUser'           => 'Aj. nouv. util.',
     'AddNewZone'           => 'Aj. nouv. zone',
     'Alarm'                => 'Alarme',
@@ -91,8 +91,8 @@ $SLANG = array(
     'Alert'                => 'Alerte',
     'All'                  => 'Tous',
     'Apply'                => 'Appliquer',
-    'ApplyingStateChange'  => 'Appl. chgt tat',
-    'ArchArchived'         => 'Archiv seul.',
+    'ApplyingStateChange'  => 'Appl. chgt état',
+    'ArchArchived'         => 'Archivé seul.',
     'ArchUnarchived'       => 'Non-arch. seul.',
     'Archive'              => 'Archiver',
     'Archived'             => 'Archived',
@@ -106,12 +106,12 @@ $SLANG = array(
     'AttrDateTime'         => 'Date/temps',
     'AttrDiskBlocks'       => 'Disk Blocks',
     'AttrDiskPercent'      => 'Disk Percent',
-    'AttrDuration'         => 'Dure',
+    'AttrDuration'         => 'Durée',
     'AttrFrames'           => 'Images',
     'AttrId'               => 'Id',
     'AttrMaxScore'         => 'Score max.',
-    'AttrMonitorId'        => 'N cran',
-    'AttrMonitorName'      => 'Nom cran',
+    'AttrMonitorId'        => 'N° écran',
+    'AttrMonitorName'      => 'Nom écran',
     'AttrName'             => 'Name',
     'AttrNotes'            => 'Notes',
     'AttrSystemLoad'       => 'System Load',
@@ -139,7 +139,7 @@ $SLANG = array(
     'BadLabelX'            => 'Label X co-ordinate must be set to an integer of zero or more',
     'BadLabelY'            => 'Label Y co-ordinate must be set to an integer of zero or more',
     'BadMaxFPS'            => 'Maximum FPS must be a positive integer or floating point value',
-    'BadNameChars'         => 'Les noms ne peuvent contenir que des lettres, chiffres, trait d\'union ou soulign',
+    'BadNameChars'         => 'Les noms ne peuvent contenir que des lettres, chiffres, trait d\'union ou souligné',
     'BadPalette'           => 'Palette must be set to a valid value', // Added - 2009-03-31
     'BadPath'              => 'Path must be set to a valid value',
     'BadPort'              => 'Port must be set to a valid number',
@@ -157,7 +157,7 @@ $SLANG = array(
     'BlobPx'               => 'Px forme',
     'BlobSizes'            => 'Taille forme',
     'Blobs'                => 'Formes',
-    'Brightness'           => 'Luminosit;',
+    'Brightness'           => 'Luminosité;',
     'Buffers'              => 'Tampons',
     'CanAutoFocus'         => 'Can Auto Focus',
     'CanAutoGain'          => 'Can Auto Gain',
@@ -204,7 +204,7 @@ $SLANG = array(
     'CapturePalette'       => 'palette capture',
     'CaptureWidth'         => 'Larg. capture',
     'Cause'                => 'Cause',
-    'CheckMethod'          => 'Mthode vrif. alarme',
+    'CheckMethod'          => 'Méthode vérif. alarme',
     'ChooseDetectedCamera' => 'Choose Detected Camera', // Added - 2009-03-31
     'ChooseFilter'         => 'Choisir filtre',
     'ChooseLogFormat'      => 'Choose a log format',    // Added - 2011-06-17
@@ -216,7 +216,7 @@ $SLANG = array(
     'Command'              => 'Command',
     'Component'            => 'Component',              // Added - 2011-06-16
     'Config'               => 'Config',
-    'ConfiguredFor'        => 'Configur pour',
+    'ConfiguredFor'        => 'Configuré pour',
     'ConfirmDeleteEvents'  => 'Are you sure you wish to delete the selected events?',
     'ConfirmPassword'      => 'Confirmer mt de pass.',
     'ConjAnd'              => 'et',
@@ -243,13 +243,13 @@ $SLANG = array(
     'Delete'               => 'Eff.',
     'DeleteAndNext'        => 'Eff. &amp; suiv.',
     'DeleteAndPrev'        => 'Eff. &amp; prec.',
-    'DeleteSavedFilter'    => 'Eff. filtre sauv',
+    'DeleteSavedFilter'    => 'Eff. filtre sauvé',
     'Description'          => 'Description',
     'DetectedCameras'      => 'Detected Cameras',       // Added - 2009-03-31
     'Device'               => 'Device',                 // Added - 2009-02-08
-    'DeviceChannel'        => 'Canal camra',
-    'DeviceFormat'         => 'Format camra',
-    'DeviceNumber'         => 'Numro camra',
+    'DeviceChannel'        => 'Canal caméra',
+    'DeviceFormat'         => 'Format caméra',
+    'DeviceNumber'         => 'Numéro caméra',
     'DevicePath'           => 'Device Path',
     'Devices'              => 'Devices',
     'Dimensions'           => 'Dimensions',
@@ -269,22 +269,22 @@ $SLANG = array(
     'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
-    'Duration'             => 'Dure',
+    'Duration'             => 'Durée',
     'Edit'                 => 'Editer',
     'Email'                => 'Courriel',
     'EnableAlarms'         => 'Enable Alarms',
-    'Enabled'              => 'Activ',
+    'Enabled'              => 'Activé',
     'EnterNewFilterName'   => 'Entrer nom nouv. filtre',
     'Error'                => 'Erreur',
-    'ErrorBrackets'        => 'Erreur, vrifiez que toutes les parenthses ouvertes sont fermes',
-    'ErrorValidValue'      => 'Erreur, vrifiez que tous les termes ont une valeur valide',
+    'ErrorBrackets'        => 'Erreur, vérifiez que toutes les parenthèses ouvertes sont fermées',
+    'ErrorValidValue'      => 'Erreur, vérifiez que tous les termes ont une valeur valide',
     'Etc'                  => 'etc',
-    'Event'                => 'Evnt',
-    'EventFilter'          => 'Filtre evnt',
+    'Event'                => 'Evènt',
+    'EventFilter'          => 'Filtre evènt',
     'EventId'              => 'Event Id',
     'EventName'            => 'Event Name',
     'EventPrefix'          => 'Event Prefix',
-    'Events'               => 'Evnts',
+    'Events'               => 'Evènts',
     'Exclude'              => 'Exclure',
     'Execute'              => 'Execute',
     'Export'               => 'Export',
@@ -332,8 +332,8 @@ $SLANG = array(
     'ForceAlarm'           => 'Force Alarme',
     'Format'               => 'Format',
     'Frame'                => 'Image',
-    'FrameId'              => 'N image',
-    'FrameRate'            => 'Dbit image',
+    'FrameId'              => 'N° image',
+    'FrameRate'            => 'Débit image',
     'FrameSkip'            => 'Saut image',
     'MotionFrameSkip'      => 'Motion Frame Skip',
     'Frames'               => 'images',
@@ -341,8 +341,8 @@ $SLANG = array(
     'Function'             => 'Fonction',
     'Gain'                 => 'Gain',
     'General'              => 'General',
-    'GenerateVideo'        => 'Gnrer Vido',
-    'GeneratingVideo'      => 'Gnration Vido',
+    'GenerateVideo'        => 'Générer Vidéo',
+    'GeneratingVideo'      => 'Génération Vidéo',
     'GoToZoneMinder'       => 'Aller sur ZoneMinder.com',
     'Grey'                 => 'Gris',
     'Group'                => 'Group',
@@ -363,7 +363,7 @@ $SLANG = array(
     'Home'                 => 'Home',
     'Hour'                 => 'Heure',
     'Hue'                  => 'Teinte',
-    'Id'                   => 'N',
+    'Id'                   => 'N°',
     'Idle'                 => 'Vide',
     'Ignore'               => 'Ignorer',
     'Image'                => 'Image',
@@ -371,7 +371,7 @@ $SLANG = array(
     'Images'               => 'Images',
     'In'                   => 'In',
     'Include'              => 'Inclure',
-    'Inverted'             => 'Invers',
+    'Inverted'             => 'Inversé',
     'Iris'                 => 'Iris',
     'KeyString'            => 'Key String',
     'Label'                => 'Label',
@@ -388,11 +388,11 @@ $SLANG = array(
     'Load'                 => 'Load',
     'Local'                => 'Local',
     'Log'                  => 'Log',                    // Added - 2011-06-16
-    'LoggedInAs'           => 'Connect c',
+    'LoggedInAs'           => 'Connecté cô',
     'Logging'              => 'Logging',                // Added - 2011-06-16
     'LoggingIn'            => 'Connexion',
     'Login'                => 'Login',
-    'Logout'               => 'Dconnexion',
+    'Logout'               => 'Déconnexion',
     'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Bas',
     'LowBW'                => 'Basse&nbsp;N/B',
@@ -430,10 +430,10 @@ $SLANG = array(
     'Message'              => 'Message',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'    => 'You must specify the minimum alarm pixel count',
-    'MinBlobAreaLtMax'     => 'Aire blob min. doit  < aire blob maximum',
+    'MinBlobAreaLtMax'     => 'Aire blob min. doit ê < aire blob maximum',
     'MinBlobAreaUnset'     => 'You must specify the minimum blob pixel count',
     'MinBlobLtMinFilter'   => 'Minimum blob area should be less than or equal to minimum filter area',
-    'MinBlobsLtMax'        => 'Blobs min. doit  < blobs max.',
+    'MinBlobsLtMax'        => 'Blobs min. doit ê < blobs max.',
     'MinBlobsUnset'        => 'You must specify the minimum blob count',
     'MinFilterAreaLtMax'   => 'Minimum filter area should be less than maximum',
     'MinFilterAreaUnset'   => 'You must specify the minimum filter pixel count',
@@ -450,7 +450,7 @@ $SLANG = array(
     'MinPanRange'          => 'Min Pan Range',
     'MinPanSpeed'          => 'Min Pan Speed',
     'MinPanStep'           => 'Min Pan Step',
-    'MinPixelThresLtMax'   => 'Seuil pixel min. doit  < seuil pixel max.',
+    'MinPixelThresLtMax'   => 'Seuil pixel min. doit ê < seuil pixel max.',
     'MinPixelThresUnset'   => 'You must specify a minimum pixel threshold',
     'MinTiltRange'         => 'Min Tilt Range',
     'MinTiltSpeed'         => 'Min Tilt Speed',
@@ -463,7 +463,7 @@ $SLANG = array(
     'MinZoomStep'          => 'Min Zoom Step',
     'Misc'                 => 'Div.',
     'Monitor'              => 'Ecran',
-    'MonitorIds'           => 'N&nbsp;cran',
+    'MonitorIds'           => 'N°&nbsp;écran',
     'MonitorPreset'        => 'Monitor Preset',
     'MonitorPresetIntro'   => 'Select an appropriate preset from the list below.<br><br>Please note that this may overwrite any values you already have configured for this monitor.<br><br>',
     'MonitorProbe'         => 'Monitor Probe',          // Added - 2009-03-31
@@ -478,27 +478,27 @@ $SLANG = array(
     'Mtg3widgrd'            => '3-wide grid',              // Added 2013.08.15.
     'Mtg4widgrd'            => '4-wide grid',              // Added 2013.08.15.
     'Mtg3widgrx'            => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
-    'MustBeGe'             => 'doit tre sup. ou gal ',
-    'MustBeLe'             => 'doit tre inf. ou gal ',
+    'MustBeGe'             => 'doit être sup. ou égal à',
+    'MustBeLe'             => 'doit être inf. ou égal à',
     'MustConfirmPassword'  => 'Confirmez le mot de passe',
     'MustSupplyPassword'   => 'Entrez un mot de passe',
     'MustSupplyUsername'   => 'Entrez un nom d\'utilisateur',
     'Name'                 => 'Nom',
     'Near'                 => 'Near',
-    'Network'              => 'Rseau',
+    'Network'              => 'Réseau',
     'New'                  => 'Nouv.',
     'NewGroup'             => 'New Group',
     'NewLabel'             => 'New Label',
     'NewPassword'          => 'Nouv. mt de passe',
-    'NewState'             => 'Nv tat',
+    'NewState'             => 'Nv état',
     'NewUser'              => 'Nv util.',
     'Next'                 => 'Suiv.',
     'No'                   => 'Non',
     'NoDetectedCameras'    => 'No Detected Cameras',    // Added - 2009-03-31
-    'NoFramesRecorded'     => 'Pas d\'image enregistre pour cet vnement',
+    'NoFramesRecorded'     => 'Pas d\'image enregistrée pour cet évènement',
     'NoGroup'              => 'No Group',
     'NoSavedFilters'       => 'Pasfiltressauv',
-    'NoStatisticsRecorded' => 'Pas de statistiques disponibles pour cet vnmnt/imag.',
+    'NoStatisticsRecorded' => 'Pas de statistiques disponibles pour cet évènmnt/imag.',
     'None'                 => 'Aucun',
     'NoneAvailable'        => 'Aucun disponible',
     'Normal'               => 'Normal',
@@ -506,12 +506,12 @@ $SLANG = array(
     'NumPresets'           => 'Num Presets',
     'Off'                  => 'Off',
     'On'                   => 'On',
-    'OpEq'                 => 'gal ',
-    'OpGt'                 => 'sup. ',
-    'OpGtEq'               => 'plus grand ou gal ',
+    'OpEq'                 => 'égal à',
+    'OpGt'                 => 'sup. à',
+    'OpGtEq'               => 'plus grand ou égal à',
     'OpIn'                 => 'en lot',
-    'OpLt'                 => 'inf. ',
-    'OpLtEq'               => 'inf. ou gal ',
+    'OpLt'                 => 'inf. à',
+    'OpLtEq'               => 'inf. ou égal à',
     'OpMatches'            => 'correspond',
     'OpNe'                 => 'diff. de',
     'OpNotIn'              => 'pas en lot',
@@ -530,9 +530,9 @@ $SLANG = array(
     'PanLeft'              => 'Pan Left',
     'PanRight'             => 'Pan Right',
     'PanTilt'              => 'Pan/Tilt',
-    'Parameter'            => 'Paramtre',
+    'Parameter'            => 'Paramètre',
     'Password'             => 'Mt de passe',
-    'PasswordsDifferent'   => 'Les 2 mots de passe sont diffrents',
+    'PasswordsDifferent'   => 'Les 2 mots de passe sont différents',
     'Paths'                => 'Paths',
     'Pause'                => 'Pause',
     'Phone'                => 'Phone',
@@ -553,11 +553,11 @@ $SLANG = array(
     'Prev'                 => 'Prec.',
     'Probe'                => 'Probe',                  // Added - 2009-03-31
     'Protocol'             => 'Protocol',
-    'Rate'                 => 'Dbit',
-    'Real'                 => 'Rel',
+    'Rate'                 => 'Débit',
+    'Real'                 => 'Réel',
     'Record'               => 'Enreg.',
     'RefImageBlendPct'     => 'Reference Image Blend %ge',
-    'Refresh'              => 'Rafrachir',
+    'Refresh'              => 'Rafraîchir',
     'Remote'               => 'Remote',
     'RemoteHostName'       => 'Remote Host Name',
     'RemoteHostPath'       => 'Remote Host Path',
@@ -572,10 +572,10 @@ $SLANG = array(
     'ReplayGapless'        => 'Gapless Events',
     'ReplaySingle'         => 'Single Event',
     'Reset'                => 'Reset',
-    'ResetEventCounts'     => 'Rem.  0 comptage des vts',
-    'Restart'              => 'Redmarrer',
-    'Restarting'           => 'Redmarrage',
-    'RestrictedCameraIds'  => 'N camras confid.',
+    'ResetEventCounts'     => 'Rem. à 0 comptage des évts',
+    'Restart'              => 'Redémarrer',
+    'Restarting'           => 'Redémarrage',
+    'RestrictedCameraIds'  => 'N° caméras confid.',
     'RestrictedMonitors'   => 'Restricted Monitors',
     'ReturnDelay'          => 'Return Delay',
     'ReturnLocation'       => 'Return Location',
@@ -599,9 +599,9 @@ $SLANG = array(
     'SelectMonitors'       => 'Select Monitors',
     'SelfIntersecting'     => 'Polygon edges must not intersect',
     'Set'                  => 'Set',
-    'SetNewBandwidth'      => 'Rgler la bande passante',
+    'SetNewBandwidth'      => 'Régler la bande passante',
     'SetPreset'            => 'Set Preset',
-    'Settings'             => 'Rglages',
+    'Settings'             => 'Réglages',
     'ShowFilterWindow'     => 'Montrerfen.filtre',
     'ShowTimeline'         => 'Show Timeline',
     'SignalCheckColour'    => 'Signal Check Colour',
@@ -620,7 +620,7 @@ $SLANG = array(
     'SpeedLow'             => 'Low Speed',
     'SpeedMedium'          => 'Medium Speed',
     'SpeedTurbo'           => 'Turbo Speed',
-    'Start'                => 'Dmarrer',
+    'Start'                => 'Démarrer',
     'State'                => 'Etat',
     'Stats'                => 'Stats',
     'Status'               => 'Statut',
@@ -633,11 +633,11 @@ $SLANG = array(
     'StepSmall'            => 'Small Step',
     'Stills'               => 'Photos',
     'Stop'                 => 'Stop',
-    'Stopped'              => 'Arrt',
+    'Stopped'              => 'Arrêté',
     'Stream'               => 'Flux',
     'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
     'Submit'               => 'Submit',
-    'System'               => 'Systme',
+    'System'               => 'Système',
     'SystemLog'            => 'System Log',             // Added - 2011-06-16
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Thumbnail',
@@ -660,17 +660,17 @@ $SLANG = array(
     'TotalBrScore'         => 'Score<br/>total',
     'TrackDelay'           => 'Track Delay',
     'TrackMotion'          => 'Track Motion',
-    'Triggers'             => 'Dclenchements',
+    'Triggers'             => 'Déclenchements',
     'TurboPanSpeed'        => 'Turbo Pan Speed',
     'TurboTiltSpeed'       => 'Turbo Tilt Speed',
     'Type'                 => 'Type',
-    'Unarchive'            => 'Dsarchiv.',
+    'Unarchive'            => 'Désarchiv.',
     'Undefined'            => 'Undefined',              // Added - 2009-02-08
-    'Units'                => 'Units',
+    'Units'                => 'Unités',
     'Unknown'              => 'Inconnu',
     'Update'               => 'Update',
-    'UpdateAvailable'      => 'Mise  jour de ZM dispo.',
-    'UpdateNotNecessary'   => 'Pas de mise  jour dispo.',
+    'UpdateAvailable'      => 'Mise à jour de ZM dispo.',
+    'UpdateNotNecessary'   => 'Pas de mise à jour dispo.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
     'UsedPlugins'	   => 'Used Plugins',
@@ -687,18 +687,18 @@ $SLANG = array(
     'VersionRemindHour'    => 'Me rappleler dans 1 h.',
     'VersionRemindNever'   => 'Ne pas avertir des nvelles versions',
     'VersionRemindWeek'    => 'Me rappeler ds 1 sem.',
-    'Video'                => 'Vido',
+    'Video'                => 'Vidéo',
     'VideoFormat'          => 'Video Format',
-    'VideoGenFailed'       => 'Echec gnration vido!',
+    'VideoGenFailed'       => 'Echec génération vidéo!',
     'VideoGenFiles'        => 'Existing Video Files',
     'VideoGenNoFiles'      => 'No Video Files Found',
-    'VideoGenParms'        => 'Paramtres gnration vido',
+    'VideoGenParms'        => 'Paramètres génération vidéo',
     'VideoGenSucceeded'    => 'Video Generation Succeeded!',
-    'VideoSize'            => 'taille vido',
+    'VideoSize'            => 'taille vidéo',
     'View'                 => 'Voir',
     'ViewAll'              => 'Voir tt',
     'ViewEvent'            => 'View Event',
-    'ViewPaged'            => 'Vue recherche',
+    'ViewPaged'            => 'Vue recherchée',
     'Wake'                 => 'Wake',
     'WarmupFrames'         => 'Images test',
     'Watch'                => 'Regarder',
@@ -710,12 +710,12 @@ $SLANG = array(
     'Wide'                 => 'Wide',
     'X'                    => 'X',
     'X10'                  => 'X10',
-    'X10ActivationString'  => 'X10:chane activation',
-    'X10InputAlarmString'  => 'X10:chane alarme entre',
-    'X10OutputAlarmString' => 'X10:chane alarme sortie',
+    'X10ActivationString'  => 'X10:chaîne activation',
+    'X10InputAlarmString'  => 'X10:chaîne alarme entrée',
+    'X10OutputAlarmString' => 'X10:chaîne alarme sortie',
     'Y'                    => 'Y',
     'Yes'                  => 'Oui',
-    'YouNoPerms'           => 'Permissions ncessaires pour cette ressource.',
+    'YouNoPerms'           => 'Permissions nécessaires pour cette ressource.',
     'Zone'                 => 'Zone',
     'ZoneAlarmColour'      => 'Couleur alarme (Red/Green/Blue)',
     'ZoneArea'             => 'Zone Area',
@@ -737,12 +737,12 @@ $SLANG = array(
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $CLANG = array(
     'CurrentLogin'         => 'Util. Actuel: \'%1$s\'',
-    'EventCount'           => '%1$s %2$s', // par ex. '37 vnts' (voir Vlang ci-dessous)
-    'LastEvents'           => '%1$s derniers %2$s', // par ex. '37 derniers  vnts' (voir Vlang ci-dessous)
-    'LatestRelease'        => 'La dernire version est v%1$s, vous avez v%2$s.',
-    'MonitorCount'         => '%1$s %2$s', // par exemple '4 crans' (voir Vlang ci-dessous)
+    'EventCount'           => '%1$s %2$s', // par ex. '37 évènts' (voir Vlang ci-dessous)
+    'LastEvents'           => '%1$s derniers %2$s', // par ex. '37 derniers  évènts' (voir Vlang ci-dessous)
+    'LatestRelease'        => 'La dernière version est v%1$s, vous avez v%2$s.',
+    'MonitorCount'         => '%1$s %2$s', // par exemple '4 écrans' (voir Vlang ci-dessous)
     'MonitorFunction'      => 'Ecran %1$s Fonction',
-    'RunningRecentVer'     => 'Vs avez la dernire version de ZoneMinder, v%s.',
+    'RunningRecentVer'     => 'Vs avez la dernière version de ZoneMinder, v%s.',
     'VersionMismatch'      => 'Version mismatch, system is version %1$s, database is %2$s.', // Added - 2011-05-25
 );
 
@@ -780,8 +780,8 @@ $CLANG = array(
 
 // Variable arrays expressing plurality, see the zmVlang description above
 $VLANG = array(
-    'Event'                => array( 0=>'vnts', 1=>'vnt', 2=>'vnts' ),
-    'Monitor'              => array( 0=>'crans', 1=>'cran', 2=>'crans' ),
+    'Event'                => array( 0=>'évènts', 1=>'évènt', 2=>'évènts' ),
+    'Monitor'              => array( 0=>'écrans', 1=>'écran', 2=>'écrans' ),
 );
 
 // You will need to choose or write a function that can correlate the plurality string arrays
