@@ -130,6 +130,7 @@ $SLANG = array(
     'BadFPSReportInterval' => 'FPS rapport interval buffer en aantal moet een nummer groter dan nul zijn',
     'BadFormat'            => 'Formaat moet een nummer nul of groter zijn',
     'BadFrameSkip'         => 'Frame skip aantal moet een nummer nul of groter zijn',
+    'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
     'BadHeight'            => 'Hoogte moet een geldige waarde zijn',
     'BadHost'              => 'Host moet een juiste address or hostname zijn, laat http:// weg ',
     'BadImageBufferCount'  => 'Foto buffer groote moet een nummer 10 of groter zijn',
@@ -150,6 +151,7 @@ $SLANG = array(
     'BadWebColour'         => 'Web kleur moeten een geldige webkleurwaarde bevatten',
     'BadWidth'             => 'Breedte moet ingevuld worden',
     'Bandwidth'            => 'Bandbreedte',
+    'BandwidthHead'        => 'Bandwidth',	// This is the end of the bandwidth status on the top of the console, different in many language due to phrasing
     'BlobPx'               => 'Blob px',
     'BlobSizes'            => 'Blob grootte',
     'Blobs'                => 'Blobs',
@@ -317,6 +319,12 @@ $SLANG = array(
     'First'                => 'Eerste',
     'FlippedHori'          => 'Horizontaal gedraait',
     'FlippedVert'          => 'Vertikaal gedraait',
+    'FnNone'                => 'None',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
+    'FnModect'              => 'Modect',            // Added 2013.08.16.
+    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
     'Focus'                => 'Focus',
     'ForceAlarm'           => 'Forceeer alarm',
     'Format'               => 'Formaat',
@@ -324,6 +332,7 @@ $SLANG = array(
     'FrameId'              => 'Frame id',
     'FrameRate'            => 'Frame rate',
     'FrameSkip'            => 'Frame overgeslagen',
+    'MotionFrameSkip'      => 'Motion Frame Skip',
     'Frames'               => 'Frames',
     'Func'                 => 'Func',
     'Function'             => 'Functie',
@@ -367,6 +376,7 @@ $SLANG = array(
     'Last'                 => 'Laatste',
     'Layout'               => 'Layout',                 // Added - 2009-02-08
     'Level'                => 'Nivo',                  // Added - 2011-06-16
+    'Libvlc'               => 'Libvlc',
     'LimitResultsPost'     => 'resultaten;', // This is used at the end of the phrase 'Limit to first N results only'
     'LimitResultsPre'      => 'beperk tot eerste', // This is used at the beginning of the phrase 'Limit to first N results only'
     'Line'                 => 'Lijn',                   // Added - 2011-06-16
@@ -460,6 +470,11 @@ $SLANG = array(
     'Month'                => 'Maand',
     'More'                 => 'Meer',                   // Added - 2011-06-16
     'Move'                 => 'Verplaats',
+    'MtgDefault'           => 'Default',              // Added 2013.08.15.
+    'Mtg2widgrd'           => '2-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrd'           => '3-wide grid',              // Added 2013.08.15.
+    'Mtg4widgrd'           => '4-wide grid',              // Added 2013.08.15.
+    'Mtg3widgrx'           => '3-wide grid, scaled, enlarge on alarm',              // Added 2013.08.15.
     'MustBeGe'             => 'Moet groter zijn of gelijk aan',
     'MustBeLe'             => 'Moet kleiner zijn of gelijk aan',
     'MustConfirmPassword'  => 'Je moet je wachtwoord bevestigen',
@@ -627,6 +642,10 @@ $SLANG = array(
     'TimeDelta'            => 'Tijd Delta',
     'TimeStamp'            => 'Tijdstempel',
     'Timeline'             => 'Tijdslijn',
+    'TimelineTip1'         => 'Pass your mouse over the graph to view a snapshot image and event details.',              // Added 2013.08.15.
+    'TimelineTip2'         => 'Click on the coloured sections of the graph, or the image, to view the event.',              // Added 2013.08.15.
+    'TimelineTip3'         => 'Click on the background to zoom in to a smaller time period based around your click.',              // Added 2013.08.15.
+    'TimelineTip4'         => 'Use the controls below to zoom out or navigate back and forward through the time range.',              // Added 2013.08.15.
     'Timestamp'            => 'Tijdstempel',
     'TimestampLabelFormat' => 'Tijdstempel Label Format',
     'TimestampLabelX'      => 'Tijdstempel Label X',
@@ -702,6 +721,7 @@ $SLANG = array(
     'ZoneMinMaxPixelThres' => 'Min/Max Pixel Threshold (0-255)',
     'ZoneMinderLog'        => 'ZoneMinder Log',         // Added - 2011-06-17
     'ZoneOverloadFrames'   => 'Overload Frame negeer aantal',
+    'ZoneExtendAlarmFrames' => 'Extend Alarm Frame Count',
     'Zones'                => 'Zones',
     'Zoom'                 => 'Zoom',
     'ZoomIn'               => 'Zoom In',
@@ -834,6 +854,20 @@ function zmVlang( $langVarArray, $count )
 // These overrides are in the form show below where the array key represents the option name minus the initial ZM_
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
+	'OPTIONS_FFMPEG' => array(
+		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
+		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+	),
+	'OPTIONS_LIBVLC' => array(
+		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		          "Examples (do not enter quotes)~~~~".
+		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
+		          "\"--verbose=2\" Set verbosity of libVLC"
+	),
+	
 //    'LANG_DEFAULT' => array(
 //        'Prompt' => "This is a new prompt for this option",
 //        'Help' => "This is some new help for this option which will be displayed in the popup window when the ? is clicked"
