@@ -70,7 +70,7 @@ if ( !isset($newZone) )
 {
     if ( $zid > 0 )
     {
-        $zone = dbFetchOne( "select * from Zones where MonitorId = '".dbEscape($monitor['Id'])."' and Id = '".dbEscape($zid)."'" );
+        $zone = dbFetchOne( 'SELECT * FROM Zones WHERE MonitorId = ? AND Id=?', NULL, array( $monitor['Id'], $zid ) );
     }
     else
     {
@@ -96,6 +96,7 @@ if ( !isset($newZone) )
             'MinBlobs' => '',
             'MaxBlobs' => '',
             'OverloadFrames' => '',
+            'ExtendAlarmFrames' => '',
         );
     }
     $zone['Points'] = coordsToPoints( $zone['Coords'] );
@@ -207,6 +208,10 @@ xhtmlHeaders(__FILE__, $SLANG['Zone'] );
                 <th scope="row"><?= $SLANG['ZoneOverloadFrames'] ?></th>
                 <td colspan="2"><input type="text" name="newZone[OverloadFrames]" value="<?= $newZone['OverloadFrames'] ?>" size="4"/></td>
               </tr>
+              <tr>
+                <th scope="row"><?= $SLANG['ZoneExtendAlarmFrames'] ?></th>
+                <td colspan="2"><input type="text" name="newZone[ExtendAlarmFrames]" value="<?= $newZone['ExtendAlarmFrames'] ?>" size="4"/></td>
+              </tr>
             </tbody>
           </table>
         </div>
